local mPhotonView, mJavaBridge = ...

local TAG = "feedback_want_app_dialog"

local SHOW_FORCED

local mAppTextWatcher = {}
local mWayTextWatcher = {}
local mIsAppInputEmpty = true
local mIsWayInputEmpty = true
local isAppInput = false
local isWayInput = false
local mAppInput
local mWayInput
local mInputMethodManager

-- 检查是否有nil
local function checkNil(...)
    local args = {...}
    for i = 1, select("#", ...) do
        if args[i] == nil then
            return true
        end
    end
    return false
end

-- 检查是否有nil
local function trim(text)
    if type(text) ~= 'string' then
        return ''
    end
    return string.gsub(text, "^%s*(.-)%s*$", "%1")
end

-- 检查是否为nil或长度为0
local function checkNilOrEmpty(text)
    if text == nil or #text == 0 then
        return true
    end
    return false
end

local function getTextString(text)
    if text == nil then
        return ""
    end
    local str = text:getView():getText():toString()
    return trim(str)
end

local function focus(edittext)
    mJavaBridge:Log(TAG, "focus")
    edittext:getView():setFocusable(true)
    edittext:getView():setFocusableInTouchMode(true)
    edittext:getView():requestFocus()
end

local function initInputMethodManager()
    mJavaBridge:Log(TAG, "initInputMethodManager")
    local Context = luajava.bindClass("android.content.Context")
    local InputMethodManager = luajava.bindClass("android.view.inputmethod.InputMethodManager")
    local mContext = mPhotonView:getParser():getContext()
    SHOW_FORCED = InputMethodManager.SHOW_FORCED
    mInputMethodManager = mContext:getSystemService(Context.INPUT_METHOD_SERVICE)
end

-- 手工调用显示软键盘，光获取焦点 是不能呼起软键盘的
local function showKeyboard(edittext)
    mJavaBridge:Log(TAG, "showKeyboard")
    if checkNil(edittext, mInputMethodManager, SHOW_FORCED) then
        return
    end
    mInputMethodManager:showSoftInput(edittext, SHOW_FORCED)
end

-- 强制隐藏键盘
local function hiddenKeyboard(edittext)
    mJavaBridge:Log(TAG, "hiddenKeyboard")
    if checkNil(edittext, mInputMethodManager) then
        return
    end
    if not mInputMethodManager:isActive() then
        return
    end
    mInputMethodManager:hideSoftInputFromWindow(edittext:getWindowToken(), 0)
end

local function updateSubmit(empty)
    mJavaBridge:Log(TAG, "updateSubmit")
    if empty then
        Rapid:getChild('submit'):setAttr("clickable", "false")
        Rapid:getChild('submit'):setAttr("textcolor", "4c0080ff")
    else
        Rapid:getChild('submit'):setAttr("clickable", "true")
        Rapid:getChild('submit'):setAttr("textcolor", "ff0080ff")
    end
end

local function finish()
    mJavaBridge:Log(TAG, "back")
    hiddenKeyboard(mAppInput:getView())
    hiddenKeyboard(mWayInput:getView())
    mJavaBridge:finish()
end

local function showToast(value)
    Rapid:execAction("customtoastaction", {
        ["value"] = value,
        ["backgroundcolor"] = "#D9000000",
        ["textcolor"] = "#FFFFFFFF",
        ["duration"] = 0,
        ["gravity"] = 17,
        ["cornerradius"] = 8,
        ["height"] = 48,
        ["textsize"] = 14,
        ["textstyle"] = "bold"
    }, nil)
end

local function report(actionid, param, extendparam)
    local reportParams = {}
    reportParams["param"] = "scene:data@scene,actionid:"..actionid..",slotid:data@slotid,sourcesceneslotid:data@sourcesceneslotid,sourcescene:data@sourcescene,sourcemodeltype:data@sourcemodeltype,searchid:data@searchId,appid:0"..param
    reportParams["extendparam"] = "report_element:pop,uni_pop_type:220,uni_pop_configid:-1,searchquery:data@queryWord,search_scene:data@searchscene,sourcequery:data@sourcequery"..extendparam
    Rapid:execAction("reportaction", reportParams, nil)
end

-- 弹窗输入上报
local function inputReport(position)
    local actionid = "231"
    local param = ",subposition:"..position
    local extendparam = ""
    report(actionid, param, extendparam)
end

-- 弹窗取消上报
local function cancelReport(uniCancelType)
    local actionid = "201"
    local param = ""
    local extendparam = ",uni_cancel_type:"..uniCancelType
    report(actionid, param, extendparam)
end

-- 点击提交上报
local function submitReport(app, way)
    local actionid = "200"
    local param = ""
    local extendparam = ",uni_button_title:提交,uni_feedback_appname:"..app..",uni_feedback_channel:"..way
    report(actionid, param, extendparam)
end

local function onRequestListener(succeed)
    mJavaBridge:Log(TAG, "onRequestListener"..string.format(" succeed: %s", tostring(succeed)))
end

local function onSubmitSuccess(app, way)
    mJavaBridge:Log(TAG, "onSubmitSuccess"..string.format(" app: %s, way: %s", app, way))
    local queryWord = Rapid:getData('queryWord', '')
    mJavaBridge:request(305, {
        ["ReportType"] = "1",
        ["FeedbackQuery"] = queryWord,
        ["FeedbackAppName"] = app,
        ["FeedbackPathOfKowningApp"] = way,
    }, onRequestListener)
    submitReport(app, way)
    showToast("建议已收到，应用上架将第一时间通知你~")
    finish()
end

local function onSubmitFailed()
    mJavaBridge:Log(TAG, "onSubmitFailed")
    showToast("提交失败，请重试")
end

local function submit(app, way)
    mJavaBridge:Log(TAG, "submit"..string.format(" app: %s, way: %s", app, way))
    if mJavaBridge:isNetworkActive() then
        onSubmitSuccess(app, way)
    else
        onSubmitFailed()
    end
end

function mAppTextWatcher.afterTextChanged(editable)
    mJavaBridge:Log(TAG, "mAppTextWatcher.afterTextChanged")
    local text = trim(editable:toString())
    mJavaBridge:Log(TAG, "mAppTextWatcher.afterTextChanged text: ["..tostring(text).."]")
    if mIsAppInputEmpty ~= checkNilOrEmpty(text) then
        mIsAppInputEmpty = not mIsAppInputEmpty
        updateSubmit(mIsAppInputEmpty)
        if (not isAppInput) and (not mIsAppInputEmpty) then
            isAppInput = true
            local position = "1"
            inputReport(position)
        end
    end
end

function mWayTextWatcher.afterTextChanged(editable)
    mJavaBridge:Log(TAG, "mTextWatcher.afterTextChanged")
    local text = trim(editable:toString())
    mJavaBridge:Log(TAG, "mTextWatcher.afterTextChanged text: ["..tostring(text).."]")
    if mIsWayInputEmpty ~= checkNilOrEmpty(text) then
        mIsWayInputEmpty = not mIsWayInputEmpty
        if (not isWayInput) and (not mIsWayInputEmpty) then
            isWayInput = true
            local position = "2"
            inputReport(position)
        end
    end
end

function loadFinish()
    mJavaBridge:Log(TAG, "loadFinish")
    initInputMethodManager()
    initInput()
end

function viewShow()
    mJavaBridge:Log(TAG, "viewShow")
    mJavaBridge:delayRun(200, runShowKeyboard)
end

function runShowKeyboard()
    focus(mAppInput)
    showKeyboard(mAppInput:getView())
end

function initInput()
    mJavaBridge:Log(TAG, "initInput")
    mAppInput = mPhotonView:getParser():getChildView("app")
    mWayInput = mPhotonView:getParser():getChildView("way")
    local appTextWatcher = luajava.createProxy('android.text.TextWatcher', mAppTextWatcher)
    local hintTextColor = mJavaBridge:parseColor('3f000000', 0)
    mWayInput:getView():setHintTextColor(hintTextColor)
    mAppInput:getView():addTextChangedListener(appTextWatcher)
    local wayTextWatcher = luajava.createProxy('android.text.TextWatcher', mWayTextWatcher)
    mWayInput:getView():setHintTextColor(hintTextColor)
    mWayInput:getView():addTextChangedListener(wayTextWatcher)
end

function onBackClick()
    mJavaBridge:Log(TAG, "onBackClick")
    local uniCancelType = "6"
    cancelReport(uniCancelType)

    finish()
end

function onKeyBack()
    mJavaBridge:Log(TAG, "onKeyBack")
    local uniCancelType = "4"
    cancelReport(uniCancelType)

    finish()
end

function onCancelClick()
    mJavaBridge:Log(TAG, "onCancelClick")
    local uniCancelType = "1"
    cancelReport(uniCancelType)

    finish()
end

function onSubmitClick()
    mJavaBridge:Log(TAG, "onSubmitClick")
    local app = getTextString(mAppInput)
    local way = getTextString(mWayInput)
    submit(app, way)
end